/*
	@name ARM project
*/

#include "..\SED1335\sed1335.h"
#include "..\SED1335\graphic.h"
#include "stm32f10x.h"

#define LEN_SIN 		200
#define BufferSize		32

uint16_t SINE_TABLE[LEN_SIN] = {
0x0800, 0x0840, 0x0881, 0x08C1, 0x0901, 0x0940, 0x0980, 0x09BF, 
0x09FD, 0x0A3B, 0x0A79, 0x0AB5, 0x0AF2, 0x0B2D, 0x0B68, 0x0BA1, 
0x0BDA, 0x0C12, 0x0C49, 0x0C7F, 0x0CB3, 0x0CE7, 0x0D19, 0x0D4A, 
0x0D79, 0x0DA7, 0x0DD4, 0x0DFF, 0x0E29, 0x0E51, 0x0E78, 0x0E9D, 
0x0EC0, 0x0EE2, 0x0F02, 0x0F20, 0x0F3C, 0x0F57, 0x0F6F, 0x0F86, 
0x0F9B, 0x0FAE, 0x0FBF, 0x0FCE, 0x0FDB, 0x0FE6, 0x0FEF, 0x0FF6, 
0x0FFB, 0x0FFE, 0x0FFF, 0x0FFE, 0x0FFB, 0x0FF6, 0x0FEF, 0x0FE6, 
0x0FDB, 0x0FCE, 0x0FBF, 0x0FAE, 0x0F9B, 0x0F86, 0x0F6F, 0x0F57, 
0x0F3C, 0x0F20, 0x0F02, 0x0EE2, 0x0EC0, 0x0E9D, 0x0E78, 0x0E51, 
0x0E29, 0x0DFF, 0x0DD4, 0x0DA7, 0x0D79, 0x0D4A, 0x0D19, 0x0CE7, 
0x0CB3, 0x0C7F, 0x0C49, 0x0C12, 0x0BDA, 0x0BA1, 0x0B68, 0x0B2D, 
0x0AF2, 0x0AB5, 0x0A79, 0x0A3B, 0x09FD, 0x09BF, 0x0980, 0x0940, 
0x0901, 0x08C1, 0x0881, 0x0840, 0x0800, 0x07C0, 0x077F, 0x073F, 
0x06FF, 0x06C0, 0x0680, 0x0641, 0x0603, 0x05C5, 0x0587, 0x054B, 
0x050E, 0x04D3, 0x0498, 0x045F, 0x0426, 0x03EE, 0x03B7, 0x0381, 
0x034D, 0x0319, 0x02E7, 0x02B6, 0x0287, 0x0259, 0x022C, 0x0201, 
0x01D7, 0x01AF, 0x0188, 0x0163, 0x0140, 0x011E, 0x00FE, 0x00E0, 
0x00C4, 0x00A9, 0x0091, 0x007A, 0x0065, 0x0052, 0x0041, 0x0032, 
0x0025, 0x001A, 0x0011, 0x000A, 0x0005, 0x0002, 0x0001, 0x0002, 
0x0005, 0x000A, 0x0011, 0x001A, 0x0025, 0x0032, 0x0041, 0x0052, 
0x0065, 0x007A, 0x0091, 0x00A9, 0x00C4, 0x00E0, 0x00FE, 0x011E, 
0x0140, 0x0163, 0x0188, 0x01AF, 0x01D7, 0x0201, 0x022C, 0x0259, 
0x0287, 0x02B6, 0x02E7, 0x0319, 0x034D, 0x0381, 0x03B7, 0x03EE, 
0x0426, 0x045F, 0x0498, 0x04D3, 0x050E, 0x054B, 0x0587, 0x05C5, 
0x0603, 0x0641, 0x0680, 0x06C0, 0x06FF, 0x073F, 0x077F, 0x07C0
};

char Hello[] = "Hello world!";

//uint32_t frequency = 1000;					// frequency of output in Hz,
                                          	// defaults to 1000 Hz

uint16_t SPI2_Buffer_Rx[BufferSize];


void InitGPIO(void)
{
   RCC->APB2ENR	|= RCC_APB2ENR_IOPCEN;		//    .     . 
											//   STM32 =)))        
   GPIOC->CRH	&= ~GPIO_CRH_CNF9;			//   CNF3 ..      (01)
											//  Open Drain.    Push-Pull (00)
 
   GPIOC->CRH   |= GPIO_CRH_MODE9_0;		//     (    , 
											//  GPIOA-CRL-MODE    (00).     
											//         . 
											//   18  RM
   GPIOC->CRH	&= ~GPIO_CRH_CNF8;
   GPIOC->CRH   |= GPIO_CRH_MODE8_0;
   /*I/O port A clock enable */
   RCC->APB2ENR	|= RCC_APB2ENR_IOPAEN;		//    	A (     DAC-a)
   /*Alternate Function I/O clock enable */
   RCC->APB2ENR	|= RCC_APB2ENR_AFIOEN;
   /* The GPIO configuration of the DAC1 ( PA4 ) outputs should be in analog Mode  */ 
   GPIOA->CRL	&= ~GPIO_CRL_CNF4;			// PA4.CNF = 00
   GPIOA->CRL   &= ~GPIO_CRL_MODE4;			// PA4.MODE = 00

   /* Set PA0 as alternate function Push-Pull for TIM2 Channel 1 ( OC1 )
      Generate 4MHz 50% duty cycle sygnal
      Connect to "CLOCK" input external ADC ADC8361*/
   GPIOA->CRL   |= GPIO_CRL_MODE0;	 		// PA0.MODE = 11
   GPIOA->CRL	&= ~GPIO_CRL_CNF0;			// PA0.CNF = 00 (Reset)
   GPIOA->CRL	|= GPIO_CRL_CNF0_1;			// PA0.CNF = 10	(Alternate function	Push-pull)

   /* set PA8 as alternate function push-pull for TIM1 OCM1
      Generate 200kHz 10% duty cycle sygnal
      Connect to "CONVST" input external ADC ADC8361 */
   GPIOA->CRH   |= GPIO_CRH_MODE8;	 		// PA8.MODE = 11
   GPIOA->CRH	&= ~GPIO_CRH_CNF8;			// PA8.CNF = 00 (Reset)
   GPIOA->CRH	|= GPIO_CRH_CNF8_1;			// PA8.CNF = 10	(Alternate function	Push-pull)

   /* set PA9 as alternate function push-pull for TIM1 OCM2
      Generate 200kHz 20% duty cycle, temporary gate sygnal
      Using with external 7400 or 7432 or 74125 chip to generate 16 clocks 4Mhz */
   GPIOA->CRH   |= GPIO_CRH_MODE9;	 		// PA9.MODE = 11
   GPIOA->CRH	&= ~GPIO_CRH_CNF9;			// PA9.CNF = 00 (Reset)
   GPIOA->CRH	|= GPIO_CRH_CNF9_1;			// PA9.CNF = 10	(Alternate function	Push-pull)

   /* Set PB0 as alternate function Push-Pull for TIM3 Channel 3 ( OC3 )
      Connect to SPI DATA to generate test signal, for check SPI */
   RCC->APB2ENR	|= RCC_APB2ENR_IOPBEN;		//     B.
   GPIOB->CRL   |= GPIO_CRL_MODE0;	 		// PB0.MODE = 11
   GPIOB->CRL	&= ~GPIO_CRL_CNF0;			// PA0.CNF = 00 (Reset)
   GPIOB->CRL	|= GPIO_CRL_CNF0_1;			// PA0.CNF = 10	(Alternate function	Push-pull)
}

/*----------------------------------------------------------------------------
  DAC1 Init Procedure
  Get TRGO event from Timer15 to start Converton
  After end Convertion grnerate request to DMA 
 *----------------------------------------------------------------------------*/
void InitDAC1(void)
{
  /* DAC interface clock enable */
  RCC->APB1ENR |= RCC_APB1ENR_DACEN;
  /*DAC channel1 output buffer disable */
  DAC->CR |= DAC_CR_BOFF1;

  /*DAC channel1 Trigger selection -> Timer3 (001) */
  DAC->CR |= DAC_CR_TSEL1_0;

  /*DAC channel1 Trigger enable */
  DAC->CR |= DAC_CR_TEN1;
  /*DAC channel1 DMA enable */
  DAC->CR |= DAC_CR_DMAEN1;
  /* DAC channel1 enable */
  DAC->CR |= DAC_CR_EN1;
}

/*----------------------------------------------------------------------------
  DMA1 Channel 3 Configuration Procedure
  Transver data from Flash to DAC1 (Gnerate sinus signal) 
 *----------------------------------------------------------------------------*/
void InitDMA1_3(void)
{
  /* DMA1 clock enable */
  RCC->AHBENR |= RCC_AHBENR_DMA1EN;

  /*Peripheral Adress*/
  DMA1_Channel3->CPAR = (uint32_t) & DAC->DHR12R1;
  /*Memory Adress*/
  DMA1_Channel3->CMAR = (u32) &SINE_TABLE;
  /*Data transfer direction - To Peripheral*/
  DMA1_Channel3->CCR |= DMA_CCR3_DIR;
  /*Number of data to be transferred*/
  DMA1_Channel3->CNDTR = LEN_SIN;				// Lenght of sin table (Buffer size)
  /*Peripheral increment mode Disable*/
  DMA1_Channel3->CCR &= ~DMA_CCR3_PINC;
  /*Memory increment mode */
  DMA1_Channel3->CCR |= DMA_CCR3_MINC;
  /*Memory size - 16bit*/
  DMA1_Channel3->CCR |= DMA_CCR3_MSIZE_0;
  /*Peripheral size - 16bit*/
  DMA1_Channel3->CCR |=	DMA_CCR3_PSIZE_0;
  /*Circular mode - Enable*/
  DMA1_Channel3->CCR |=	DMA_CCR3_CIRC;
  /*Channel Priority level - High) */
  DMA1_Channel3->CCR |=	DMA_CCR3_PL_1;
  /*Memory to memory mode - Disable */
  DMA1_Channel3->CCR &= ~DMA_CCR3_MEM2MEM;
  /*DMA1 Channel3 enable */
  DMA1_Channel3->CCR |= DMA_CCR3_EN;
}

/*----------------------------------------------------------------------------
  TIM1 Init procedte -> set timer as counter with autoreload; 
  Input Frq 8MHz; reload 200kHz; 8MHz/200kHz=40clocks (2 clock TIM1-> 1 ADC Cicle) 
  Configured in Slave mode, managed from Timer4
  TIM1_CH1 connected to "Conversion Start" (CONVST) input, externel ADC ADS8361 
  TIM1_CH2 connected to "enable" (NSS) pin SPI1 and SPI2
*----------------------------------------------------------------------------*/
void InitTmr1 (void)
{
  RCC->APB2ENR |= RCC_APB2ENR_TIM1EN;		//    

  TIM1->ARR = 39;							//    40 (0..39)  (8MHz/200kHz=40)
  TIM1->PSC = 0;							// -   = 1 ->   = TIM4_Reload
  TIM1->CR1 &= (~TIM_CR1_CKD);				//   = 1
  /* Generate an update event to reload the Prescaler value immediatly */
  TIM1->EGR	= 0x0001;

  /* Set TIM1 Slave Mode to "External Clock Mode 1" */
  TIM1->SMCR |= TIM_SMCR_SMS;

  /* Set TIM1 to get the input trigger from TIM4 (ITR3; TS = 011) */
  TIM1->SMCR |= (TIM_SMCR_TS_1 | TIM_SMCR_TS_0);

  /* Set OCM1 Main output -> enable */
  TIM1->BDTR |= TIM_BDTR_MOE;

  TIM1->BDTR |= TIM_BDTR_OSSR; 

  /* Set dead time -> 1 ADC Clock (4MHz) == 6PCLC (peripheral clock 24MHz) */
  TIM1->BDTR |= 6;

 
 /* TIM1 Output compare module 1 -> PWM1 Mode 1 + dead time
    Generate 200kHz 10% duty cycle sygnal
    Connect to "CONVST" input external ADC ADC8361
    TIM1_CH1 output is displayed on PA8 */
  TIM1->CCR1 = 6; // 3 clock * 2

  /* Set OCM1 mode -> PWM mode 1 */
  TIM1->CCMR1 |= ( TIM_CCMR1_OC1M_1 | TIM_CCMR1_OC1M_2 );

  /* Set OCM1 preload -> enable */
  TIM1->CCMR1 |= TIM_CCMR1_OC1PE;

  /* Set OCM1 Polarity -> Active High*/
  TIM1->CCER &= ~TIM_CCER_CC1P;

  /* Set OCM1 complemetary output -> enable
     (enable dead time generator)  */
  TIM1->CCER |= (TIM_CCER_CC1E | TIM_CCER_CC1NE);
 
 /* TIM1 Output compare module 2 -> PWM1 Mode 20% duty cycle
	Using for generate "Enable" (NSS) signal to SPI1 and SPI2 modules
	ADC cicle is 20 clocks long with 16 cl. data => 4 cl. inactive time
  	TIM1_CH2 output is displayed on PA9  */
  TIM1->CCR2 = 8; // (4 tact * 2)

  /* Set OCM2 mode -> PWM mode 1
  "PWM mode 1" active as long as TIM1_CNT < TIM1_CCR2 
  "PWM mode 2" active as long as TIM1_CNT > TIM1_CCR2 */
  TIM1->CCMR1 |= ( TIM_CCMR1_OC2M_1 | TIM_CCMR1_OC2M_2 );

  /* Set OCM2 preload -> enable */
  TIM1->CCMR1 |= TIM_CCMR1_OC2PE;

  /* Set OCM2 Polarity -> Active Low*/
  TIM1->CCER &= ~TIM_CCER_CC2P;

  /* TIM1 CCM2 output enable */
  TIM1->CCER |= TIM_CCER_CC2E;
  

  /* TIM1 enable counter */
  TIM1->CR1 |= TIM_CR1_CEN;					//  

  /* In DEBUG Mode Stop the Timer1 */
  DBGMCU->CR |= DBGMCU_CR_DBG_TIM1_STOP; 
}

/*----------------------------------------------------------------------------
  TIM2 Init procedte -> set timer as counter with autoreload; freqency = 4Mhz
  Configured in Slave "External Clock Mode 1", managed from Timer4
  TIM2 OCM1 set in PWM Mode2 (50% duty cycle) -> pin PA0, connected to "CLOCK" 
  input external ADC ADS8361
 *----------------------------------------------------------------------------*/
void InitTmr2 (void)
{
  RCC->APB1ENR |= RCC_APB1ENR_TIM2EN;		//    

  TIM2->ARR = 1;							//    2 (0..1)  (8MHz/4MHz=2)
  TIM2->PSC = 0;							// -   = 1 ->   = SysClc
  TIM2->CR1 &= (~TIM_CR1_CKD);				//   = 1
  /* Generate an update event to reload the Prescaler value immediatly */
  TIM2->EGR	= 0x0001;

  /* Set TIM2 in slave mode -> "External Clock Mode 1" */
  TIM2->SMCR |= TIM_SMCR_SMS;

  /* Set TIM1 to get the input trigger from TIM4 (ITR3; TS = 011) */
  TIM2->SMCR |= (TIM_SMCR_TS_1 | TIM_SMCR_TS_0);


/* Set OCM1 register -> PWM1 Mode duty cycle = 50% */
  TIM2->CCR1 = 1;  // 1 -> ( 2*50% )

  /* Set OCM1 mode -> PWM mode 1
  "PWM mode 1" active as long as TIM2_CNT < TIM2_CCR1 
  "PWM mode 2" active as long as TIM2_CNT > TIM2_CCR1*/
  TIM2->CCMR1 |= ( TIM_CCMR1_OC1M_1 | TIM_CCMR1_OC1M_2 );

  /* Set OCM1 preload -> enable */
  TIM2->CCMR1 |= TIM_CCMR1_OC1PE;

  /* Set the Output Compare 3 Polarity -> Active Low 
  0: OCx active high; 1: OCx active low. */
  TIM2->CCER &= ~TIM_CCER_CC1P;

  /* Set CCM1 output -> enable */
  TIM2->CCER |= TIM_CCER_CC1E;


  /* TIM2 enable counter */
  TIM2->CR1 |= TIM_CR1_CEN;					//  

  /* In DEBUG Mode Stop the Timer2 */
  DBGMCU->CR |= DBGMCU_CR_DBG_TIM2_STOP; 
}

/*----------------------------------------------------------------------------
  TIM3 Init procedte -> set timer as counter with autoreload; 
  Input Frq 8MHz; reload 200kHz; 8MHz/200kHz=40clocks (2 clock TIM1-> 1 ADC Cicle) 
  Configured in Slave "External Clock Mode 1", managed from Timer4
  Generate "update event" to start DAC1
  TIM3_CH3 generate test signal -> "DATA" to check SPI
*----------------------------------------------------------------------------*/
void InitTmr3 (void)
{
  RCC->APB1ENR |= RCC_APB1ENR_TIM3EN;		//    

  TIM3->ARR = 39;							//    40 (0..39)  (8MHz/200kHz=40)
  TIM3->PSC = 0;							// -   = 1 ->   = TIM4_Reload
  TIM3->CR1 &= (~TIM_CR1_CKD);				//   = 1
  /* Generate an update event to reload the Prescaler value immediatly */
  TIM3->EGR	= 0x0001;

  /* Set TIM3 TRGO -> Update*/
  TIM3->CR2 |= TIM_CR2_MMS_1;

  /* Set TIM3 Slave Mode to "External Clock Mode 1" */
  TIM3->SMCR |= TIM_SMCR_SMS;

  /* Set TIM3 to get the input trigger from TIM4 (ITR3; TS = 011) */
  TIM3->SMCR |= (TIM_SMCR_TS_1 | TIM_SMCR_TS_0);


/* Set OCM1 register -> PWM1 Mode duty cycle = 50% 
   Using to generate data to SPI for test*/
  TIM3->CCR3 = 24;  // 1 -> ( 2*50% )

  /* TIM3 CCM3 mode selection -> PWM mode 1
  "PWM mode 1" active as long as TIM3_CNT < TIM3_CCR3 
  "PWM mode 2" active as long as TIM3_CNT > TIM3_CCR3*/
  TIM3->CCMR2 |= ( TIM_CCMR2_OC3M_1 | TIM_CCMR2_OC3M_2 );

  /* TIM3 Output compare 3 preload enable */
  TIM3->CCMR2 |= TIM_CCMR2_OC3PE;

  /* Set the Output Compare 3 Polarity -> Active Low 
  0: OCx active high; 1: OCx active low. */
  TIM3->CCER |= TIM_CCER_CC3P;

  /* TIM3 CCM3 output enable */
  TIM3->CCER |= TIM_CCER_CC3E;


  /* TIM3 enable counter */
  TIM3->CR1 |= TIM_CR1_CEN;					//  

  /* In DEBUG Mode Stop the Timer3 */
  DBGMCU->CR |= DBGMCU_CR_DBG_TIM3_STOP; 
}


/*----------------------------------------------------------------------------
  TIM4 Init procedte -> set timer as counter with autoreload; 
  Reload Freqency = 8MHz
  Using as Master timer -> generate clock signal to TIM1, TIM2, TIM3
 *----------------------------------------------------------------------------*/
void InitTmr4 (void)
{
  RCC->APB1ENR |= RCC_APB1ENR_TIM4EN;		//    

  TIM4->ARR = 2;							//    3 (0..2)  (24MHz/8MHz=3)
  TIM4->PSC = 0;							// -   = 1 ->   = SysClc
  TIM4->CR1 &= (~TIM_CR1_CKD);				//   = 1
  /* Generate an update event to reload the Prescaler value immediatly */
  TIM4->EGR	= 0x0001;

  /* Set TIM4 TRGO -> update event is selected as trigger output*/
  TIM4->CR2 |= TIM_CR2_MMS_1;
 
  /* TIM4 enable counter */
  TIM4->CR1 |= TIM_CR1_CEN;					//  

  /* In DEBUG Mode Stop the Timer4 */
  DBGMCU->CR |= DBGMCU_CR_DBG_TIM4_STOP; 
}


/*----------------------------------------------------------------------------
  SPI2 Init procedte -> set SPI2 module in slave 16bit mode
  NSS (CS)	= PB12 (Input Pull-Up)
  CLK 		= PB13 (Input Pull-Up)
  SDI(MISO) = PB14 (Alternative Function, Push Pull)   (   )
  SDO(MOSI) = PB15 (Input Pull-Up)
*----------------------------------------------------------------------------*/

void SPI2Config()
{
  RCC->APB1ENR |= RCC_APB1ENR_SPI2EN;	// SPI2 clock enable
  SPI2->CR1 &= ~SPI_CR1_SPE;			// SPI2 disable

  SPI2->CR1 &= ~SPI_CR1_BIDIMODE;		// 2-line unidirectional data mode selected
  SPI2->CR1 &= ~SPI_CR1_BIDIOE;			// Output disabled (receive-only mode)
  SPI2->CR1 |= SPI_CR1_DFF;				// data frame format = 16bit
  SPI2->CR1 &= ~SPI_CR1_LSBFIRST;		// MSB transmitted first
  SPI2->CR1 |= SPI_CR1_RXONLY;			// Output disabled (Receive-only mode)
  SPI2->CR1 &= ~SPI_CR1_SSM; 			// enable hardware slave management	(Use NSS pin)
  SPI2->CR1 &= ~SPI_CR1_MSTR; 			// configure as slave
  SPI2->CR1 |= SPI_CR1_CPOL; 			// CPOL = 1	  see p.510 in DS
  SPI2->CR1 |= SPI_CR1_CPHA; 			// CPHA = 1
  SPI2->CR2 |= SPI_CR2_RXDMAEN;			// Rx buffer DMA enabled

  SPI2->CR1 |= SPI_CR1_SPE;  			// SPI2 enable
}

/*----------------------------------------------------------------------------
  DMA Channel_4 Configuration Procedure ( Mapped to SPI2_RX see p.149 in DS)
  Transver 16bit value from SPI2 to SPI2_Buffer_Rx circular buffer
 *----------------------------------------------------------------------------*/
void InitDMA1_4(void)
{
  /* DMA1 clock enable */
  RCC->AHBENR |= RCC_AHBENR_DMA1EN;

  /*Peripheral Adress*/
  DMA1_Channel4->CPAR = (uint32_t) &SPI2->DR;
  /*Memory Adress*/
  DMA1_Channel4->CMAR = (uint32_t) &SPI2_Buffer_Rx;
  /*Data transfer direction - To Memory*/
  DMA1_Channel4->CCR &= ~DMA_CCR4_DIR;
  /*Number of data to be transferred*/
  DMA1_Channel4->CNDTR = BufferSize;				// Lenght of circilar buffer (Buffer size)
  /*Peripheral increment mode -> Disable*/
  DMA1_Channel4->CCR &= ~DMA_CCR4_PINC;
  /*Memory increment mode -> Enable*/
  DMA1_Channel4->CCR |= DMA_CCR4_MINC;
  /*Memory size - 16bit*/
  DMA1_Channel4->CCR |= DMA_CCR4_MSIZE_0;
  /*Peripheral size - 16bit*/
  DMA1_Channel4->CCR |=	DMA_CCR4_PSIZE_0;
  /*Circular mode -> Enable*/
  DMA1_Channel4->CCR |=	DMA_CCR4_CIRC;
  /*Channel Priority level - High) */
  DMA1_Channel4->CCR |=	DMA_CCR4_PL_1;
  /*Memory to memory mode - Disable */
  DMA1_Channel4->CCR &= ~DMA_CCR4_MEM2MEM;
  /*DMA Transfer complete interupt -> Enable*/
  DMA1_Channel4->CCR |=	DMA_CCR4_TCIE;

  /*DMA1 Channel2 enable */
  DMA1_Channel4->CCR |= DMA_CCR4_EN;
}



void InitNVIC(void)
{
  /*   SPI2   36 .      
     (  1) "Set Enable Register" ->   36-32 -> 4-  */ 
  NVIC->ISER[1] |= NVIC_ICER_CLRENA_4;

  /*   DMA Channel_4   14 .      
     (  0) "Set Enable Register" ->   -> 14-  */
  NVIC->ISER[0] |= NVIC_ICER_CLRENA_14;
}


void DMA1_Channel4_IRQHandler(void)
{
extern void itoa(char * qbuf, int n);
char BCD_Value [6];
uint8_t i;

    DMA1->IFCR |= DMA_IFCR_CGIF4;   // clear interupt flag
   	for(i = 0; i < 32; i++){
	  itoa(BCD_Value, SPI2_Buffer_Rx[i]);
	  if (i==((i/2)*2)) GLCD_TextGoTo(2,(i/2));
	  else GLCD_TextGoTo(15,(i/2));
	  GLCD_WriteText(BCD_Value); 
	}
   __NOP();
}

void SPI2_IRQHandler(void)
{
   __NOP();
}



/*******************************************************************************
* Function Name  : Delay
* Description    : Inserts a delay time.
* Input          : nCount: specifies the delay time length.
* Output         : None
* Return         : None
*******************************************************************************/
void Delay(uint32_t nCount)
{
  for (; nCount != 0; nCount--);
}

/*******************************************************************************/


void itoa( char * qbuf, int n )
{
register int r, k;
int flag = 0;
int next = 0;

   for(r = 0; r < 6; r++) qbuf[r] = ' ';
   if (n < 0) {
      qbuf[next++] = '-';
      n = -n;
   }
   if (n == 0) {
        qbuf[next++] = '0';
   } else {
        k = 10000;
        while (k > 0) {
             r = n / k;
             if (flag || r > 0) {
                qbuf[next++] = '0' + r;
                flag = 1;
             }
             n -= r * k;
             k = k / 10;
         }
   }
   qbuf[next] = 0;
}


int main(void)
{

  InitGPIO();
  GPIOC->BSRR =GPIO_BSRR_BS8;

  Delay(200000);							// Give time LCD wake Up
  GLCD_Initialize(TEXT);				// TEXT or GRAPHICS
  GLCD_TextGoTo(8,5);
  GLCD_WriteText(Hello);
  GLCD_Rectangle(40,20,150,120);

  GPIOC->BSRR =GPIO_BSRR_BS9;

  InitNVIC();
  InitDMA1_4();							// Transver Data from SPI2 to SPI2_Buffer_Rx[]
  InitDMA1_3();							// Transver Data from SinTable[] to DAC1
  SPI2Config();							// Read data from external ADC (slave mode)
  InitDAC1();							// generate sinus signal
  InitTmr1();							// generate managed signals to SPI1, SPI2, External ADC 
  InitTmr2();							// Generate clock signal to SPI1, SPI2, External ADC
  InitTmr3();							// Start convertion DAC
  InitTmr4();							// Master timer; Start/Stop DAC, ADC

while(1)
  {

  }
} 


